import { Injectable } from '@angular/core';
import { User } from './services/user';
import { auth } from 'firebase/app';
import { Router, ActivatedRoute } from '@angular/router';
import { AngularFireAuth } from '@angular/fire/auth';
import { AngularFirestore, AngularFirestoreDocument } from '@angular/fire/firestore';
import { ServiceService } from './../config/service.service';
import { MyordersService } from './../config/myorder.service';
import { from } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  userData: any;

  constructor(
    public afs: AngularFirestore,
    public afAuth: AngularFireAuth,
    private router: Router,
    private service: ServiceService,
    public myorder: MyordersService
  ) {
      this.afAuth.authState.subscribe(user => {
        if (user) {
          this.userData = user;
          this.service.set('user', JSON.stringify(this.userData));
        } else {
          this.service.set('user', null);
          JSON.parse(localStorage.getItem('user'));
        }
      });
  }

  public async SignIn(email: string, password: string) {
    return this.afAuth.auth.signInWithEmailAndPassword(email, password).then((result) => {
      console.log('success');
      this.router.navigateByUrl('home');
      this.SetUserData(result.user);
    }).catch((error) => {
      window.alert(error.message);
    });
  }

  get isLoggedIn(): boolean {
    const user = JSON.parse(localStorage.getItem('user'));
    return (user !== null && user.emailVerified !== false) ? true : false;
  }

  SetUserData(user: any) {
    console.log(user);
    const userRef: AngularFirestoreDocument<any> = this.afs.doc(`riders/${user.uid}`);
    userRef.valueChanges().subscribe((value) => {
      console.log(value);
      const userData: User = {
        riderId: value.riderId,
        emailId: value.emailId,
        name: value.name,
        profilePhoto: value.profilePic,
        phone: value.phone,
        onlineStatus: value.onlineStatus,
        regNo: value.regNo,
        fraudStatus: value.fraudStatus,
        location: value.location,
        vehicle: value.vehicle,
        verified: value.verified,
        currOrder: value.currOrder,
        rideState: value.rideState
        };
      console.log(userData);
      /* if (value.rideState === true) {
        this.router.navigateByUrl('riderlounge');
      } else {
        this.router.navigateByUrl('home');
      }
      document.body.scrollTop = document.documentElement.scrollTop = 0;*/
    });
  }

  public async SignOut() {
    return this.afAuth.auth.signOut().then(() => {
      this.service.remove('user');
      console.log('logout');
    });
  }


}
